close all

%%%defining colors
cmap=[ 
    0    0.4470    0.7410
    0.8500    0.3250    0.0980
    0.9290    0.6940    0.1250
    0.4940    0.1840    0.5560
    0.4660    0.6740    0.1880
    0.3010    0.7450    0.9330
    0.6350    0.0780    0.1840];

    SampleUnClAll=[Data1(:,1)  Data2(:,1)  Data3(:,1)  Data4(:,1)  Data5(:,1)  Data6(:,1) ];
    SampleClAll=[Data1(:,2)  Data2(:,2)  Data3(:,2)  Data4(:,2)  Data5(:,2)  Data6(:,2) ];

%%%Fitting Data
%%%cleaved and uncleaved were fitted with an global k
[Param1,Fun1,tv1]=Fit(Data1,Errors,time);
[Param2,Fun2,tv2]=Fit(Data2,Errors,time);
[Param3,Fun3,tv3]=Fit(Data3,Errors,time);
[Param4,Fun4,tv4]=Fit(Data4,Errors,time);
[Param5,Fun5,tv5]=Fit(Data5,Errors,time);
[Param6,Fun6,tv6]=Fit(Data6,Errors,time);

%%%%Averaging parameters
%%amplitide cleaved product
AClmean=mean([Param1(1) Param2(1) Param3(1) Param4(1) Param5(1) Param6(1)]);
AClstd=std([Param1(1) Param2(1) Param3(1) Param4(1) Param5(1) Param6(1)]);
%%amplitide uncleaved substrate
i=2;
AUClmean=mean([Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
AUClstd=std([Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
%%first order rate constant k and first order time constant tau 
i=3;
kmean=mean(1./[Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
kstd=std(1./[Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
taumean=mean([Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
taustd=std([Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
%%constant offset for cleaved product
i=4;
cClmean=mean([Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
cClstd=std([Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
%%constant offset for uncleaved substrate
i=5;
cUClmean=mean([Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
cUClstd=std([Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
%%offset in time
i=6;
toffmean=mean([Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);
toffstd=std([Param1(i) Param2(i) Param3(i) Param4(i) Param5(i) Param6(i)]);

%%FRET correction value
FRETcorrection=AClmean/AUClmean;

%%Plot results
figure(1)
    Faktor=1e6;
    tvmore=0:0.1:60.2;
        F2=(AClmean-AClmean*exp(-tvmore/taumean)+cClmean)/Faktor;
        F1=(cUClmean+(AUClmean-cUClmean)*exp(-tvmore/taumean))/Faktor;
    h1=plot(tvmore,F2,'linewidth',1);
    hold on
    h2=plot(tvmore,F1,'linewidth',1);
        errorbar(time,mean(SampleClAll,2)/Faktor,std(SampleClAll')/Faktor,'o','color',cmap(1,:),'linewidth',1)
         errorbar(time,mean(SampleUnClAll,2)/Faktor,std(SampleUnClAll')/Faktor,'o','color',cmap(2,:),'linewidth',1)
    plot([0 80],([AClmean AClmean]+cClmean)/Faktor,'--','color',[0.5 0.5 0.5])
    text(tvmore(end)+1,  (AClmean+cClmean)/Faktor+1 , sprintf('%.2f  %.2f',[roundsd(AClmean/Faktor,3) roundsd(AClstd/Faktor,2)]))
    plot([0 80],([AUClmean AUClmean]+cUClmean)/Faktor,'--','color',[0.5 0.5 0.5])
    text(tvmore(end)+1,  (AUClmean+cUClmean)/Faktor+1 , sprintf('%.2f  %.2f',[roundsd(AUClmean/Faktor,3) roundsd(AUClstd/Faktor,2)]))
    xlabel('Time (min)');
    ylabel('Band intensity')
    box off
    hold off


clear cmap Faktor ans F1 F2 h1 h2 i tvmore`